@@ -20,8 +20,9 @@ use warnings;
 use Carp;
 use FileHandle;
 use Data::Dumper;
+use Scalar::Util qw(weaken);
 
-our $VERSION = 1.07;
+our $VERSION = '1.09';
 our $DEBUG   = 0;
 
 sub new
@@ -41,7 +42,9 @@ sub add
 	$outline->{'id'}     = shift;
 	$outline->{'name'}   = shift;
 	$outline->{'Parent'} = $self;
+	weaken $outline->{Parent};
 	$outline->{'pdf'}    = $self->{'pdf'};
+	weaken $outline->{pdf};
 	my %params = @_;
 	$outline->{'Title'}  = $params{'Title'}  if defined $params{'Title'};
 	$outline->{'Action'} = $params{'Action'} if defined $params{'Action'};
